Contours in OpenCV {#tutorial_table_of_contents_contours}
==================

-   @subpage tutorial_find_contours

    *Languages:* C++, Java, Python

    *Compatibility:* \> OpenCV 2.0

    *Author:* Ana Huamán

    Where we learn how to find contours of objects in our image

-    @subpage tutorial_hull

    *Languages:* C++, Java, Python

    *Compatibility:* \> OpenCV 2.0

    *Author:* Ana Huamán

    Where we learn how to get hull contours and draw them

-   @subpage tutorial_bounding_rects_circles

    *Languages:* C++, Java, Python

    *Compatibility:* \> OpenCV 2.0

    *Author:* Ana Huamán

    Where we learn how to obtain bounding boxes and circles for our contours

-   @subpage tutorial_bounding_rotated_ellipses

    *Languages:* C++, Java, Python

    *Compatibility:* \> OpenCV 2.0

    *Author:* Ana Huamán

    Where we learn how to obtain rotated bounding boxes and ellipses for our contours

-   @subpage tutorial_moments

    *Languages:* C++, Java, Python

    *Compatibility:* \> OpenCV 2.0

    *Author:* Ana Huamán

    Where we learn to calculate the moments of an image

-   @subpage tutorial_point_polygon_test

    *Languages:* C++, Java, Python

    *Compatibility:* \> OpenCV 2.0

    *Author:* Ana Huamán

    Where we learn how to calculate distances from the image to contours
